@@ -129,6 +129,7 @@ class Panda(QtGui.QMainWindow):
 			self.ui = Ui_pyRadio()
 			self.ui.setupUi(self)
 			self.connect_signals()
+			self.portrait = False
 			if not self.player.curSong == 0:
 				self.setUi ( self.player.curSong )
 				self.buildPlaylist()
@@ -136,6 +137,7 @@ class Panda(QtGui.QMainWindow):
 			self.ui = Ui_pyRadio_portrait()
 			self.ui.setupUi(self)
 			self.connect_signals()
+			self.portrait = True
 			if not self.player.curSong == 0:
 				self.setUi ( self.player.curSong )
 				self.buildPlaylist()
@@ -177,6 +179,11 @@ class Panda(QtGui.QMainWindow):
 
 	def open_donate( self ):
 		self.d = QDialog(self)
+		self.d.setParent(self)
+		if not self.portrait:
+			self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+		else:
+			self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		vbox = QVBoxLayout()
 		hLayout = QHBoxLayout()
 		m = QPushButton("pyRadio")
